@@ -59,12 +59,12 @@ std::vector<std::string> buildDepends(const std::string regexp = ".") {
 
     pkgSourceList *List = cacheFile.GetSourceList();
     if (unlikely(List == NULL))
-        return res;
+        return res;             // #nocov
 
     // Create the text record parsers
     pkgSrcRecords SrcRecs(*List);
     if (_error->PendingError() == true)
-        return res;
+        return res;		// #nocov
 
     for (pkgCache::PkgIterator pkg = cache->PkgBegin(); !pkg.end(); pkg++) {
         if (pkgre(pkg)) {
@@ -121,20 +121,24 @@ bool showSrc(const std::string regexp = ".") {
     APT::CacheFilter::PackageNameMatchesRegEx pkgre(regexp);
 
     pkgSourceList *List = cacheFile.GetSourceList();
-    if (unlikely(List == NULL))
+    if (unlikely(List == NULL)) {		// nocov  start
+        Rcpp::Rcout << "Error: No cached sources list. Maybe you have src-deb entries?\n";
         return false;
+    } 						// nocov end
 
     // Create the text record parsers
     pkgSrcRecords SrcRecs(*List);
-    if (_error->PendingError() == true)
+    if (_error->PendingError() == true)	{	// nocov  start
+        Rcpp::Rcout << "Error: No sources records. Maybe you have src-deb entries?\n";
         return false;
+    }						// nocov end
 
     unsigned found = 0;
 
     for (pkgCache::PkgIterator pkg = cache->PkgBegin(); !pkg.end(); pkg++) {
         if (pkgre(pkg)) {
             const std::string pkgstr = pkg.FullName(true);
-            //Rcpp::Rcout << "--" << pkgstr << std::endl;
+            Rcpp::Rcout << "--" << pkgstr << std::endl;
             SrcRecs.Restart();
       
             pkgSrcRecords::Parser *Parse;
@@ -145,16 +149,16 @@ bool showSrc(const std::string regexp = ".") {
                 found_this++;
                 //Rcpp::Rcout << "(" << found << "," << found_this << ")" << std::endl;
             }
-            // if (found_this == 0) {
+            //if (found_this == 0) {
             //     //_error->Warning(_("Unable to locate package %s"),*I);
             //     Rcpp::stop("Unable to locate package");
             //     continue;
-            // }
+            //}
         }
     }
     if (found == 0)
         //_error->Notice(_("No packages found"));
-        return false;
+        return false;		// #nocov
     return true;
 }
 
